pub struct Operator {
pub address: Address,
pub delegation_approver_address: Address,
pub metadata_url: String,
pub allocation_delay: Option<u32>,
pub _deprecated_earnings_receiver_address: Option<Address>,
pub staker_opt_out_window_blocks: Option<u32>,
}Expand description
Operator represents EigenLayer’s view of an operator
Fields
address: AddressOperator Address
delegation_approver_address: Addressmetadata_url: StringMetadataUrl URL where operator metadata is stored
allocation_delay: Option<u32>allocation_delay is the delay in seconds where an operator is allowed to change allocation
This can only be set once by the operator. Once set this can’t be changed
_deprecated_earnings_receiver_address: Option<Address>staker_opt_out_window_blocks: Option<u32>Implementations
Sourceimpl Operator
impl Operator
pub fn new( address: &str, delegation_approver_address: &str, metadata_url: String, allocation_delay: Option<u32>, _deprecated_earnings_receiver_address: Option<Address>, staker_opt_out_window_blocks: Option<u32>, ) -> Result<Self, OperatorTypesError>
pub async fn validate(&self) -> Result<(), OperatorTypesError>
pub fn operator_id_from_key_pair( keypair: BlsKeyPair, ) -> Result<OperatorId, OperatorTypesError>